@@ -4,7 +4,7 @@
 #         Martin Senger <martin.senger@gmail.com>
 # For copyright and disclaimer see below.
 #
-# $Id: Base.pm,v 1.21 2009-12-03 18:44:11 ubuntu Exp $
+# $Id: Base.pm,v 1.28 2010-02-11 00:02:51 ubuntu Exp $
 #-----------------------------------------------------------------
 package SADI::Base;
 use strict;
@@ -32,8 +32,8 @@ use overload q("")    => "as_string";
 BEGIN {
 	@ISA      = qw( Exporter );
 	@EXPORT   = qw( $LOG );
-	$VERSION  = sprintf "%d.%02d", q$Revision: 1.21 $ =~ /: (\d+)\.(\d+)/;
-	$Revision = '$Id: Base.pm,v 1.21 2009-12-03 18:44:11 ubuntu Exp $';
+	$VERSION  = sprintf "%d.%02d", q$Revision: 1.28 $ =~ /: (\d+)\.(\d+)/;
+	$Revision = '$Id: Base.pm,v 1.28 2010-02-11 00:02:51 ubuntu Exp $';
 
 	# initiate error handling
 	require Carp;
@@ -158,7 +158,7 @@ sub toString {
 sub module_name_escape {
 	my ( $self, $name ) = @_;
 	$name =~ tr/-/_/;
-	$name =~ tr/~//;
+	$name =~ s/~//g;
 	return $name;
 }
 
@@ -202,6 +202,8 @@ sub uri2package {
 		  . $lsid->namespace . '#'
 		  . $lsid->object;
 	}
+	# strip off any '.owl' bits from the URI
+	$uri =~ s/\.owl//gi;
 	my $u1 = URI->new($uri);
 
 	# the domain from the uri
@@ -222,6 +224,9 @@ sub uri2package {
 
 	# remove leading /
 	$path =~ s/^\///g;
+	
+	# sub fragment with : to _ 
+	$path =~ s/:/_/g;
 
 	# convert / and . to ::
 	$path =~ s/\/|\./::/g;
@@ -849,6 +854,18 @@ was set to true).
 
 =head1 LOGGING
 
+Logging is available through the $LOG variable create and exported as a result of using this module.
+
+As a service writer, you can $LOG->info('some message'), $LOG->warn('some warning'),
+ $LOG->debug('some debug statement') or $LOG->error('some error message').
+
+The next question is where are these messages sent? SADISeS allows you to 
+configure where to send messages in the log4perl.properties file. When 
+you run sadi-install.pl this module, this file is automatically created 
+for you and placed (usually) in your home directory in a folder called 
+Perl-SADI. If no properties file exists, then the messages are usually 
+placed in STDOUT.
+
 =head1 OTHER SUBROUTINES
 
 =head2 new
@@ -949,9 +966,9 @@ Without any parameter, it stringifies the caller object
 #   
 #   Example:
 #    uri given: 
-#      http://sadiframework.org/examples/regression.owl#DatedValue   
+#      http://sadiframework.org/examples/regression#DatedValue   
 #    package returned:
-#      sadiframework::org::examples::regression::owl
+#      sadiframework::org::examples::regression
 #
 #-----------------------------------------------------------------
 
