@@ -4,7 +4,7 @@
 #         Edward Kawas
 # For copyright and disclaimer see below.
 #
-# $Id: Core.pm,v 1.13 2009-12-03 18:42:36 ubuntu Exp $
+# $Id: Core.pm,v 1.19 2010-03-09 17:36:14 ubuntu Exp $
 #-----------------------------------------------------------------
 package SADI::RDF::Core;
 use strict;
@@ -12,6 +12,7 @@ use strict;
 use Carp;
 
 use Template;
+ 
 use FindBin qw( $Bin );
 use lib $Bin;
 use File::Spec;
@@ -30,11 +31,11 @@ use base ("SADI::Base");
 
 # add versioning to this module
 use vars qw /$VERSION/;
-$VERSION = sprintf "%d.%02d", q$Revision: 1.13 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.19 $ =~ /: (\d+)\.(\d+)/;
 
 =head1 NAME
 
-     SADI::RDF::Core -- A Perl package for SADI services
+SADI::RDF::Core - A Perl package for SADI services
 
 =head1 DESCRIPTION
 
@@ -223,7 +224,7 @@ sub getInputNodes {
 	  RDF::Core::Resource->new("http://www.w3.org/1999/02/22-rdf-syntax-ns#type");
 	my $inputtype = RDF::Core::Resource->new($predicate);
 
-#  we need the input types to be "Input" because a client can honestly send us a more complex type that inherits and it wpont be understood without a reasoner
+#  we need the input types to be "Input" because a client can honestly send us a more complex type that inherits and it wont be understood without a reasoner
 
 	my $yesno = $model->existsStmt( undef, $type, $inputtype );
 	return () unless $yesno;
@@ -291,9 +292,9 @@ sub getLiteralPropertyValues {
       subject   => the URI of the subject for which you want to retrieve statements for
       object    => the URI of the object for which you want to retrieve statements for
       predicate => the URI of the predicate for which you want to retrieve statements for
-  
+
   B<subject, object and predicate are all optional.>
-  
+
   returns
       a reference to an array of RDF::Core::Statements that match the given subject, object and predicate
 
@@ -351,9 +352,9 @@ sub getStatements {
   %args
       subject   => the URI of the subject for which you want to retrieve objects for
       predicate => the URI of the predicate for which you want to retrieve objects for
-  
+
   B<subject, object and predicate are all optional.>
-  
+
   returns
       a reference to an array of RDF::Core::Resource that match the given subject and predicate
 
@@ -392,11 +393,11 @@ sub getObjects {
 
   add an output triple to the model; the predicate of the triple
   is automatically extracted from the ServicePredicate.
-  
+
   You can pass a URI or an RDF::Core::Resource as the "value" argument.  
   The node is automatically rdf:typed as the OutputClass if you include
   the "typed_as_output" argument as true.
-  
+
   If you pass a "value" that looks like a URI, then this routine WILL ASSUME
   THAT YOU WANT IT TO BE AN OBJECT, NOT A SCALAR VALUE.  To over-ride this,
   set the boolean "force_literal" argument.  If you pass an RDF::Core::Resource
@@ -404,21 +405,20 @@ sub getObjects {
   will be extracted and added as a literal value rather than as an object.
 
   args
-     
+
      node => $URI  (the URI string, RDF::Core::Resource of the subject node or 
-             a SADI::Data::OWL::Class (object generated using sadi-generate-datatypes)).
+             a OWL::Data::OWL::Class (object generated using sadi-generate-datatypes)).
              In the event of an OWL class, all other args are ignored.
-     
+
      value => $val  (a string value)
-     
-     predicate => $URI (required unless node isa SADI::Data::OWL::Class- the predicate to put between them.)
-     
+
+     predicate => $URI (required unless node isa OWL::Data::OWL::Class- the predicate to put between them.)
+
      typed_as_output => boolean (if present output is rdf:typed as output class)
-     
+
      force_literal => boolean
-     
+
      label => $label (string); label for value node, only if value is a URI
-     
 
 =cut
 
@@ -428,7 +428,7 @@ sub addOutputData {
 	my $subject     = $args{node};
 	if ( ref($subject) =~ /RDF::Core::Resource/ ) {
 		$subject = RDF::Core::Resource->new( $subject->getURI );
-	} elsif ( UNIVERSAL::isa($subject, 'SADI::Data::OWL::Class') ) {
+	} elsif ( UNIVERSAL::isa($subject, 'OWL::Data::OWL::Class') ) {
 		# using generated modules, so get their statements and return
 		foreach ( @{ $subject->_get_statements } ) {
             $self->_addToModel( statement => $_ );
@@ -559,7 +559,7 @@ sub serializeOutputModel {
   according to the SADI best-practices, the service URL should return the
   interface document if you call it with GET.  Here we auto-generate that
   document.
- 
+
   $service->getServiceInterface()
 
 =cut
@@ -580,10 +580,14 @@ sub getServiceInterface {
 	my $authoritative = $self->Signature->Authoritative();
 	my $authority     = $self->Signature->Authority() ;
 	my $sigURL        = $self->Signature->SignatureURL() || "";
+	my @tests         = $self->Signature->UnitTest || ();
 
 	# generate from template
 	my $sadi_interface_signature= '';
-	my $tt = Template->new( ABSOLUTE => 1, TRIM => 1 );
+	my $tt = Template->new( 
+	   ABSOLUTE => 1, 
+	   TRIM => 1, 
+	);
 	my $input = File::Spec->rel2abs(
 					  SADI::Utils->find_file(
 						  $Bin, 'SADI', 'Generators', 'templates', 'service-signature.tt'
@@ -606,6 +610,7 @@ sub getServiceInterface {
 					 authoritative => $authoritative,
 					 authority     => $authority,
 					 sigURL        => $sigURL,
+					 tests         => @tests,
 				  },
 				  \$sadi_interface_signature
 	) || $LOG->logdie( $tt->error() );
